# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class V1VariableReference(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source': 'str',
        'source_argument': 'V1VariableRefArgument',
        'source_constant': 'V1VariableRefConstant',
        'source_step': 'V1VariableRefStep'
    }

    attribute_map = {
        'source': 'source',
        'source_argument': 'source_argument',
        'source_constant': 'source_constant',
        'source_step': 'source_step'
    }

    def __init__(self, source=None, source_argument=None, source_constant=None, source_step=None, local_vars_configuration=None):  # noqa: E501
        """V1VariableReference - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._source = None
        self._source_argument = None
        self._source_constant = None
        self._source_step = None
        self.discriminator = None

        self.source = source
        if source_argument is not None:
            self.source_argument = source_argument
        if source_constant is not None:
            self.source_constant = source_constant
        if source_step is not None:
            self.source_step = source_step

    @property
    def source(self):
        """Gets the source of this V1VariableReference.  # noqa: E501


        :return: The source of this V1VariableReference.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this V1VariableReference.


        :param source: The source of this V1VariableReference.  # noqa: E501
        :type source: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501
        allowed_values = ["argument", "step", "constant"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `source` ({0}), must be one of {1}"  # noqa: E501
                .format(source, allowed_values)
            )

        self._source = source

    @property
    def source_argument(self):
        """Gets the source_argument of this V1VariableReference.  # noqa: E501


        :return: The source_argument of this V1VariableReference.  # noqa: E501
        :rtype: V1VariableRefArgument
        """
        return self._source_argument

    @source_argument.setter
    def source_argument(self, source_argument):
        """Sets the source_argument of this V1VariableReference.


        :param source_argument: The source_argument of this V1VariableReference.  # noqa: E501
        :type source_argument: V1VariableRefArgument
        """

        self._source_argument = source_argument

    @property
    def source_constant(self):
        """Gets the source_constant of this V1VariableReference.  # noqa: E501


        :return: The source_constant of this V1VariableReference.  # noqa: E501
        :rtype: V1VariableRefConstant
        """
        return self._source_constant

    @source_constant.setter
    def source_constant(self, source_constant):
        """Sets the source_constant of this V1VariableReference.


        :param source_constant: The source_constant of this V1VariableReference.  # noqa: E501
        :type source_constant: V1VariableRefConstant
        """

        self._source_constant = source_constant

    @property
    def source_step(self):
        """Gets the source_step of this V1VariableReference.  # noqa: E501


        :return: The source_step of this V1VariableReference.  # noqa: E501
        :rtype: V1VariableRefStep
        """
        return self._source_step

    @source_step.setter
    def source_step(self, source_step):
        """Sets the source_step of this V1VariableReference.


        :param source_step: The source_step of this V1VariableReference.  # noqa: E501
        :type source_step: V1VariableRefStep
        """

        self._source_step = source_step

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1VariableReference):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1VariableReference):
            return True

        return self.to_dict() != other.to_dict()
