# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class V1Execution(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'arguments': 'dict[str, str]',
        'execution_number': 'int',
        'organization_name': 'str',
        'pipeline_name': 'str',
        'project_name': 'str'
    }

    attribute_map = {
        'arguments': 'arguments',
        'execution_number': 'execution_number',
        'organization_name': 'organization_name',
        'pipeline_name': 'pipeline_name',
        'project_name': 'project_name'
    }

    def __init__(self, arguments=None, execution_number=None, organization_name=None, pipeline_name=None, project_name=None, local_vars_configuration=None):  # noqa: E501
        """V1Execution - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._arguments = None
        self._execution_number = None
        self._organization_name = None
        self._pipeline_name = None
        self._project_name = None
        self.discriminator = None

        self.arguments = arguments
        self.execution_number = execution_number
        self.organization_name = organization_name
        self.pipeline_name = pipeline_name
        self.project_name = project_name

    @property
    def arguments(self):
        """Gets the arguments of this V1Execution.  # noqa: E501


        :return: The arguments of this V1Execution.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this V1Execution.


        :param arguments: The arguments of this V1Execution.  # noqa: E501
        :type arguments: dict[str, str]
        """
        if self.local_vars_configuration.client_side_validation and arguments is None:  # noqa: E501
            raise ValueError("Invalid value for `arguments`, must not be `None`")  # noqa: E501

        self._arguments = arguments

    @property
    def execution_number(self):
        """Gets the execution_number of this V1Execution.  # noqa: E501


        :return: The execution_number of this V1Execution.  # noqa: E501
        :rtype: int
        """
        return self._execution_number

    @execution_number.setter
    def execution_number(self, execution_number):
        """Sets the execution_number of this V1Execution.


        :param execution_number: The execution_number of this V1Execution.  # noqa: E501
        :type execution_number: int
        """
        if self.local_vars_configuration.client_side_validation and execution_number is None:  # noqa: E501
            raise ValueError("Invalid value for `execution_number`, must not be `None`")  # noqa: E501

        self._execution_number = execution_number

    @property
    def organization_name(self):
        """Gets the organization_name of this V1Execution.  # noqa: E501


        :return: The organization_name of this V1Execution.  # noqa: E501
        :rtype: str
        """
        return self._organization_name

    @organization_name.setter
    def organization_name(self, organization_name):
        """Sets the organization_name of this V1Execution.


        :param organization_name: The organization_name of this V1Execution.  # noqa: E501
        :type organization_name: str
        """
        if self.local_vars_configuration.client_side_validation and organization_name is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_name`, must not be `None`")  # noqa: E501

        self._organization_name = organization_name

    @property
    def pipeline_name(self):
        """Gets the pipeline_name of this V1Execution.  # noqa: E501


        :return: The pipeline_name of this V1Execution.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_name

    @pipeline_name.setter
    def pipeline_name(self, pipeline_name):
        """Sets the pipeline_name of this V1Execution.


        :param pipeline_name: The pipeline_name of this V1Execution.  # noqa: E501
        :type pipeline_name: str
        """
        if self.local_vars_configuration.client_side_validation and pipeline_name is None:  # noqa: E501
            raise ValueError("Invalid value for `pipeline_name`, must not be `None`")  # noqa: E501

        self._pipeline_name = pipeline_name

    @property
    def project_name(self):
        """Gets the project_name of this V1Execution.  # noqa: E501


        :return: The project_name of this V1Execution.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this V1Execution.


        :param project_name: The project_name of this V1Execution.  # noqa: E501
        :type project_name: str
        """
        if self.local_vars_configuration.client_side_validation and project_name is None:  # noqa: E501
            raise ValueError("Invalid value for `project_name`, must not be `None`")  # noqa: E501

        self._project_name = project_name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Execution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Execution):
            return True

        return self.to_dict() != other.to_dict()
