# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPipelineStepSpecEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pipeline_spec': 'OrmPipelineSpec',
        'run_spec': 'OrmRunSpec',
        'step_executions': 'list[OrmPipelineStepExecution]'
    }

    attribute_map = {
        'pipeline_spec': 'pipeline_spec',
        'run_spec': 'run_spec',
        'step_executions': 'step_executions'
    }

    def __init__(self, pipeline_spec=None, run_spec=None, step_executions=None, local_vars_configuration=None):  # noqa: E501
        """OrmPipelineStepSpecEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._pipeline_spec = None
        self._run_spec = None
        self._step_executions = None
        self.discriminator = None

        if pipeline_spec is not None:
            self.pipeline_spec = pipeline_spec
        if run_spec is not None:
            self.run_spec = run_spec
        if step_executions is not None:
            self.step_executions = step_executions

    @property
    def pipeline_spec(self):
        """Gets the pipeline_spec of this OrmPipelineStepSpecEdges.  # noqa: E501


        :return: The pipeline_spec of this OrmPipelineStepSpecEdges.  # noqa: E501
        :rtype: OrmPipelineSpec
        """
        return self._pipeline_spec

    @pipeline_spec.setter
    def pipeline_spec(self, pipeline_spec):
        """Sets the pipeline_spec of this OrmPipelineStepSpecEdges.


        :param pipeline_spec: The pipeline_spec of this OrmPipelineStepSpecEdges.  # noqa: E501
        :type pipeline_spec: OrmPipelineSpec
        """

        self._pipeline_spec = pipeline_spec

    @property
    def run_spec(self):
        """Gets the run_spec of this OrmPipelineStepSpecEdges.  # noqa: E501


        :return: The run_spec of this OrmPipelineStepSpecEdges.  # noqa: E501
        :rtype: OrmRunSpec
        """
        return self._run_spec

    @run_spec.setter
    def run_spec(self, run_spec):
        """Sets the run_spec of this OrmPipelineStepSpecEdges.


        :param run_spec: The run_spec of this OrmPipelineStepSpecEdges.  # noqa: E501
        :type run_spec: OrmRunSpec
        """

        self._run_spec = run_spec

    @property
    def step_executions(self):
        """Gets the step_executions of this OrmPipelineStepSpecEdges.  # noqa: E501


        :return: The step_executions of this OrmPipelineStepSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepExecution]
        """
        return self._step_executions

    @step_executions.setter
    def step_executions(self, step_executions):
        """Sets the step_executions of this OrmPipelineStepSpecEdges.


        :param step_executions: The step_executions of this OrmPipelineStepSpecEdges.  # noqa: E501
        :type step_executions: list[OrmPipelineStepExecution]
        """

        self._step_executions = step_executions

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPipelineStepSpecEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPipelineStepSpecEdges):
            return True

        return self.to_dict() != other.to_dict()
